@@ -46,7 +46,6 @@ static int cut_comments(char *line)
 				for (; *line && *line != closing; line++);
 				if (!*line) {
 					send_log(LOG_ERR, "Error, umatched `%c'\n", closing);
-					/* fprintf(stderr, "Error, umatched `%c'\n", closing); */
 					exit(1);
 					return 1; /* error, unmatched "*" */
 				}
@@ -187,6 +186,15 @@ static int get_uri(char *domain, struct uri_t *uri)
 	*(path++) = '\0';
 	*dend = '\0';
 
+#ifdef ENABLE_EXEC
+	if(strcmp(domain,"exec")==0) {
+		if(path[0]!='/') {
+			send_log(LOG_ERR,"Path must start with /");
+			exit(1);
+		}
+	}
+#endif /* ENABLE_EXEC*/
+
 	/* FIXME: checking whether file isgraph() all the way */
 
 	uri->domain = strdup(domain);
@@ -287,14 +295,12 @@ static int get_pattern(char *pat, struct test_t *test)
 			match.regex.code = pcre_compile(pat, 0 /* PCRE_CASELESS */, &error, &n, NULL);
 			if (!match.regex.code) {
 				send_log(LOG_ERR, "PCRE compilation failed at offset %d: %s\nPattern being compiled was: /%s/\n", n, error, pat);
-				/* fprintf(stderr, "PCRE compilation failed at offset %d: %s\nPattern being compiled was: /%s/\n", n, error, pat); */
 				exit(2);
 			}
 
 			match.regex.extra = pcre_study(match.regex.code, 0, &error);
 			if (error) {
 				send_log(LOG_ERR, "PCRE studying failed: %s\nPattern being studied was: /%s/\n", error, pat);
-				/* fprintf(stderr, "PCRE studying failed: %s\nPattern being studied was: /%s/\n", error, pat); */
 				exit(2);
 			}
 
@@ -309,8 +315,6 @@ static int get_pattern(char *pat, struct test_t *test)
 #else
 			send_log(LOG_ERR, "This version is not compiled with libpcre support.\n");
 			send_log(LOG_ERR, "Please make sure libpcre is installed and recompile.\n");
-			/* fprintf(stderr, "This version is not compiled with libpcre support.\n");
-			fprintf(stderr, "Please make sure libpcre is installed and recompile.\n"); */
 			exit(2);
 #endif /* HAVE_LIBPCRE */
 		}
@@ -329,7 +333,6 @@ static int get_pattern(char *pat, struct test_t *test)
 
 			if (!rrdfile) {
 				send_log(LOG_ERR, "RRD file name must be given first; in pattern \"%s\".\n", pat);
-				/* fprintf(stderr, "RRD file name must be given first; in pattern \"%s\".\n", pat); */
 				exit(3);
 			}
 			
@@ -340,13 +343,11 @@ static int get_pattern(char *pat, struct test_t *test)
 
 			if (!*store && i < match.count) {
 				send_log(LOG_ERR, "Not enough targets in pattern \"%s\"!!!\n", pat);
-				/* fprintf(stderr, "Not enough targets in pattern \"%s\"!!!\n", pat); */
 				exit(3);
 			}
 		}
 		if (*store) {
 			send_log(LOG_ERR, "Too many targets in pattern \"%s\"!!!\n", pat);
-			/* fprintf(stderr, "Too many targets in pattern \"%s\"!!!\n", pat); */
 			exit(3);
 		}
 
@@ -401,7 +402,6 @@ int parse_conf(const char *conf_file)
 
 		/* Something else?  Blame it on user and do a se-puku! */
 		send_log(LOG_ERR, "Unrecognized config line:\n%s\n", buf);
-		/* fprintf(stderr, "Unrecognized config line:\n%s\n", buf); */
 		fclose(conf);
 		exit(2);
 	}
