@@ -58,16 +58,16 @@ int no_fork = 0;
 const char *workdir = NULL;
 int step = 60;
 int debugoutput = OUTPUT_SYSLOG;
-int debuglevel = LOG_DEBUG;  /* from syslog.h */
+int debuglevel = LOG_NOTICE;  /* from syslog.h */
 /* FIXME - it should be default LOG_NOTICE or LOG_WARNING, but first
    option for change it should be added */
 
 /* signals */
 volatile int action_request = 0;
 
-void do_nothing(int signum) { }
+void do_nothing(__attribute__ ((unused)) int signum) { }
 void do_action(int signum) { action_request = signum; }
-void do_abort(int signum) {
+void do_abort(__attribute__ ((unused)) int signum) {
 	fprintf(stderr, "\nSegmentation fault (core dumped), but The Memory Remains.\n\n");
 	fflush(stderr);
 	abort();
@@ -138,19 +138,15 @@ void write_pid(void) {
 }
 
 /* data delivery */
-/* FIXME: this verbosity is ugly! */
 int print_update(int argc, char **argv)
 {
 	int i;
 	for (i = 0; i < argc && argv[i]; i++) {
 		fprintf(rrdtool, (i) ? " %s" : "%s", argv[i]);
 		if (verbose)
-			send_log(LOG_INFO, (i) ? " %s" : "%s", argv[i]);
-			/* fprintf(stderr, (i) ? " %s" : "%s", argv[i]); */
+			send_log(LOG_DEBUG, (i) ? " %s" : "%s", argv[i]);
 	}
 	putc('\n', rrdtool);
-	if (verbose)
-		putc('\n', stderr);
 
 	return 0;
 }
@@ -165,7 +161,7 @@ int rrdlib_update(int argc, char **argv)
 
 	if (rrd_test_error()) {
 		send_log(LOG_ERR, "rrd_update: %s\n", rrd_get_error());
-		/* fprintf(stderr, "rrd_update: %s\n", rrd_get_error()); */
+		/* FIXME-ac error handling */
 		rrd_clear_error();
 		
 		return 1;
@@ -177,8 +173,22 @@ int rrdlib_update(int argc, char **argv)
 
 int (*make_update)(int argc, char **argv);
 
+
 int set_config_variable(const char *name, const char *value)
 {
+#define strpar(a) {#a,a}
+	struct {char *f; int v;} lls[]={
+		strpar(LOG_EMERG),
+		strpar(LOG_ALERT),
+		strpar(LOG_CRIT),
+		strpar(LOG_ERR),
+		strpar(LOG_WARNING),
+		strpar(LOG_NOTICE),
+		strpar(LOG_INFO),
+		strpar(LOG_DEBUG),
+		{NULL,-1}
+	};
+#undef strpar
 	switch (*name) {
 		case 'd':
 			if (!strcmp(name, "directory")) {
@@ -186,12 +196,25 @@ int set_config_variable(const char *name, const char *value)
 				return 0;
 			}
 			break;
+		case 'l':
+			if(!strcmp(name, "loglevel")) {
+				int i=0;
+				debuglevel = LOG_WARNING;
+				while(lls[i].v!=-1) {
+					if(!strcmp(value,lls[i].f)) {
+						debuglevel = lls[i].v;
+						break;
+					}
+					++i;
+				}
+				printf("Have: %d\n", debuglevel);
+				return 0;
+			}
 		case 's':
 			if (!strcmp(name, "step")) {
 				step = atoi(value);
 				if (!step) {
 					send_log(LOG_ERR, "Invalid step value: %s (%d)\n", value, step);
-					/* fprintf(stderr, "Invalid step value: %s (%d)\n", value, step); */
 					exit(3);
 				}
 				return 0;
@@ -282,6 +305,10 @@ int main(int argc, char **argv)
 
 	struct sigaction action;
 	struct itimerval period;
+	int loop;
+
+	/* for safe exec:// */
+	setenv("IFS"," \t\n",1);
 
 	/* command line options */
 
@@ -353,7 +380,6 @@ int main(int argc, char **argv)
 
 	if (parse_conf(config_file)) {
 		send_log(LOG_ERR, "Cannot parse config file %s: %s\n", config_file, strerror(errno));
-		/* fprintf(stderr, "Cannot parse config file %s: %s\n", config_file, strerror(errno)); */
 		return 2;
 	}
 
@@ -362,16 +388,12 @@ int main(int argc, char **argv)
 		send_log(LOG_ERR, "If you're desperate, you can use something like this:\n");
 		send_log(LOG_ERR, "    # current directory:\n");
 		send_log(LOG_ERR, "    directory = .\n");
-		/* fprintf(stderr, "You have to give working directory in config file\n");
-		fprintf(stderr, "If you're desperate, you can use something like this:\n");
-		fprintf(stderr, "    # current directory:\n");
-		fprintf(stderr, "    directory = .\n"); */
 		return 2;
 	}
 
 	start_log();
 
-	send_log(LOG_INFO,"We just started");
+	send_log(LOG_NOTICE,"%s started",argv[0]);
 
 	if(is_another_copy()) {
 		send_log(LOG_ERR,"Another copy of program is running, exiting\n");
@@ -400,7 +422,6 @@ int main(int argc, char **argv)
 			}
 			if (!rrdtool) {
 				send_log(LOG_ERR, "Failed opening %s: %s\n", output_file, strerror(errno));
-				/* fprintf(stderr, "Failed opening %s: %s\n", output_file, strerror(errno)); */
 				return 3;
 			}
 		} else if (mode == PIPE_MODE) {
@@ -409,7 +430,6 @@ int main(int argc, char **argv)
 			send_log(LOG_INFO,"Update method: pipe");
 			if (!rrdtool) {
 				send_log(LOG_ERR, "Failed opening pipe %s: %s\n", output_pipe, strerror(errno));
-				/* fprintf(stderr, "Failed opening pipe %s: %s\n", output_pipe, strerror(errno)); */
 				return 3;
 			}
 			make_update = &print_update;
@@ -421,7 +441,6 @@ int main(int argc, char **argv)
 
 	if (chdir(workdir)) {
 		send_log(LOG_ERR, "Cannot chdir to %s: %s\n", workdir, strerror(errno));
-		/* fprintf(stderr, "Cannot chdir to %s: %s\n", workdir, strerror(errno)); */
 		return 2;
 	}
 
@@ -478,16 +497,15 @@ int main(int argc, char **argv)
 	period.it_interval.tv_usec = period.it_value.tv_usec = 0;
 	setitimer(ITIMER_REAL, &period, NULL);
 
-	for (;;) {
-		send_log(LOG_DEBUG,"tick");
+	loop = 1;
+	while (loop) {
 		if (action_request) {
 			switch (action_request) {
 				case SIGINT:
 				case SIGQUIT:
 				case SIGTERM:
-					/* FIXME: better leave for(;;) loop... */
-					send_log(LOG_INFO,"Signal received. Exitting...");
-					exit(0);
+					send_log(LOG_NOTICE,"Signal received. Preparing to exit...");
+					loop=0;
 					break;
 					
 				case SIGHUP:
@@ -508,4 +526,6 @@ int main(int argc, char **argv)
 
 		pause();
 	}
+	/* Freeing the resources */
+	unlink(PIDFILE); /* FIXME-ac error handling */
 }
