@@ -74,6 +74,11 @@ int scan(const char *buf, const char *fmt, struct counter_t **counter)
 						} while (isdigit(*fmt));
 					}
 
+					/* skip white spaces like scanf does */
+					if (strchr("difuoxX", *fmt))
+						while (isspace(*buf))
+							buf++;
+					
 					/* FIXME: we should check afterward:
 					 * if (start == buf || start == '-' && buf-start == 1)
 					 * 	die("WTF???  zero-length number???");
@@ -101,7 +106,7 @@ int scan(const char *buf, const char *fmt, struct counter_t **counter)
 
 
 							/* ignore if value not found */
-							if(start == buf || atoi(start) == '-' && buf-start == 1)
+							if((start == buf) || ((atoi(start) == '-') && (buf-start == 1)))
 								break;
 
 							if (!ignore)
@@ -150,27 +155,22 @@ int scan(const char *buf, const char *fmt, struct counter_t **counter)
 								buf++, length--;
 							}
 
-							/* ignore if value not found */
-							if(value == 0)
-								return 0;
-
 							if (!ignore)
-								counter[i++]->value = valuedup(value);
+								counter[i++]->value = strndup(start, buf - start);
 							break;
 							
 						case 'c':
+							if (length < 0)
+							     length = 1;	// default length is 1
+							
 							while (*buf && length > 0) {
 								buf++, length--;
 							}
 							if (length > 0)
 								return 2;
 
-							/* ignore if value not found */
-							if(value == 0)
-								return 0;
-							
 							if (!ignore)
-								counter[i++]->value = valuedup(value);
+								counter[i++]->value = strndup(start, buf - start);
 							break;
 							
 							
@@ -192,7 +192,7 @@ int scan(const char *buf, const char *fmt, struct counter_t **counter)
 			case '\f':
 			case '\v':
 				/* don't match if not at least one space */
-				if(!isspace(*(buf)))
+				if(!isspace(*buf))
 					return 0;
 				else
 					buf++;
@@ -208,7 +208,7 @@ int scan(const char *buf, const char *fmt, struct counter_t **counter)
 					case '\v':
 						break;
 					default:
-						while (isspace(*(buf)))
+						while (isspace(*buf))
 							buf++;
 				}
 				fmt++;
@@ -263,13 +263,11 @@ int regscan(const char *bp, const struct match_t *match)
 		return 1; /* no match */
 	} else if (rc < 0) {
 		send_log(LOG_ERR, "Regex matching error %d!\n", rc);
-		/* fprintf(stderr, "Regex matching error %d!\n", rc); */
 		return 1;
 	}
 	
 	if (rc == 0) {
-		send_log(LOG_ERR, "Regex overctor too small!!! Should not be happening!\n");
-		/* fprintf(stderr, "Regex overctor too small!!! Should not be happening!\n"); */
+		send_log(LOG_ERR, "Regex ovector too small!!! Should not be happening!\n");
 		rc = match->count + 1;
 	}
 		
